<?php
/**
 * Provide a admin area view for the plugin
 *
 * This file is used to markup the feeds listing aspects of the plugin.
 *
 * @link       https://makewebbetter.com
 * @since      1.0.0
 *
 * @package    Mwb_Cf7_Integration_With_Zoho
 * @subpackage Mwb_Cf7_Integration_With_Zoho/admin/partials/templates
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

$_feeds = Mwb_Cf7_Integration_With_Zoho_Helper::get_feeds();
$_forms = Mwb_Cf7_Integration_With_Zoho_Helper::get_contact_forms();

?>
<div class="mwb-zcf7__feedlist-wrap">
	<div class="mwb-zcf7__logo-wrap">
		<div class="mwb-zcf7__logo-zoho">
			<img src="<?php echo esc_url( ZOHO_CF7_INTEGRATION_URL . 'admin/images/zoho-logo.png' ); ?>" alt="<?php esc_html_e( 'Zoho', 'mwb-cf7-integration-with-zoho' ); ?>">
		</div>
		<div class="mwb-zcf7__logo-contact">
			<img src="<?php echo esc_url( ZOHO_CF7_INTEGRATION_URL . 'admin/images/contact-form.svg' ); ?>" alt="<?php esc_html_e( 'Zoho', 'mwb-cf7-integration-with-zoho' ); ?>">
		</div>
		<div class="mwb-zcf7__newfeed">
			<a href="<?php echo esc_url( admin_url( 'post-new.php?post_type=mwb_zoho_feeds' ) ); ?>" ><?php esc_html_e( 'Add New Feed', 'mwb-cf7-integration-with-zoho' ); ?></a>
		</div>
		<div class="mwb-zcf7__filterfeed">
			<Select class="filter-feeds-by-form" name="filter-feeds-by-form" >
				<option value="-1"><?php esc_html_e( 'Select CF7 form', 'mwb-cf7-integration-with-zoho' ); ?></option>
				<option value="all"><?php esc_html_e( 'All Feeds', 'mwb-cf7-integration-with-zoho' ); ?></option>
				<?php if ( ! empty( $_forms ) && is_array( $_forms ) ) : ?>
					<?php foreach ( $_forms as $_id => $val ) : ?>
						<option value="<?php echo esc_html( $val->ID ); ?>"><?php echo esc_html( $val->post_title ); ?></option>
					<?php endforeach; ?>
				<?php endif; ?>
			</Select>
		</div>
	</div>

	<div>
		<ul class="mwb-zcf7__feed-list">
		<?php foreach ( $_feeds as $feed ) : ?>

			<?php $_status = get_post_status( $feed->ID ); ?>
			<?php $_form = get_post_meta( $feed->ID, 'mwb_zcf7_form', true ); ?>
			<?php $_object = get_post_meta( $feed->ID, 'mwb_zcf7_object', true ); ?>
			<?php $_prime_key = get_post_meta( $feed->ID, 'mwb_zcf7_primary_field', true ); ?>

			<li class="mwb-zcf7__feed-row">
				<div class="mwb-zcf7__left-col">
					<h3><?php echo esc_html( $feed->post_title ); ?></h3>
					<div class="mwb-feed-status__wrap">
						<p class="mwb-feed-status-text_<?php echo esc_attr( $feed->ID ); ?>" ><strong><?php echo esc_html( 'publish' == $_status ? 'Active' : 'Sandbox' ); // @codingStandardsIgnoreLine ?></strong></p>
					<p><input type="checkbox" class="mwb-feed-status" value="publish" <?php checked( 'publish', $_status ); ?> feed-id=<?php echo esc_attr( $feed->ID ); ?> ></p>
					</div>
					<p><label><strong><?php esc_html_e( 'Form : ', 'mwb-cf7-integration-with-zoho' ); ?></strong><?php echo esc_html( ! empty( $_form ) && '-1' != $_form ? sanitize_text_field( wp_unslash( get_the_title( $_form ) ) ) : '' ); // @codingStandardsIgnoreLine ?></label></p>
					<p><label><strong><?php esc_html_e( 'Object : ', 'mwb-cf7-integration-with-zoho' ); ?></strong><?php echo esc_html( ! empty( $_object ) && '-1' != $_object ? sanitize_text_field( wp_unslash( $_object ) ) : '' );  // @codingStandardsIgnoreLine ?></label></p>
					<p><label><strong><?php esc_html_e( 'Primary key : ', 'mwb-cf7-integration-with-zoho' ); ?></strong><?php echo esc_html( ! empty( $_prime_key ) && '-1' != $_prime_key ? sanitize_text_field( wp_unslash( $_prime_key ) ) : '' ); // @codingStandardsIgnoreLine ?></label></p>
				</div>
				<div class="mwb-zcf7__right-col">
					<a href="<?php echo esc_url( get_edit_post_link( $feed->ID ) ); ?>"><img src="<?php echo esc_url( ZOHO_CF7_INTEGRATION_URL . 'admin/images/edit.svg' ); ?>" alt="<?php esc_html_e( 'Edit feed', 'mwb-cf7-integration-with-zoho' ); ?>"></a>
					<div class="mwb-zcf7__right-col1">
					<a href="javascript:void(0)" class="mwb_zcf7__trash_feed" feed-id="<?php echo esc_html( $feed->ID ); ?>"><img src="<?php echo esc_url( ZOHO_CF7_INTEGRATION_URL . 'admin/images/trash.svg' ); ?>" alt="<?php esc_html_e( 'Trash feed', 'mwb-cf7-integration-with-zoho' ); ?>"></a>
				</div>
				</div>
			</li>
		<?php endforeach; ?>
		</ul>
	</div>
</div>
