<?php
/**
 * Provide a admin area view for the plugin
 *
 * This file is used to markup the zoho logs listing aspects of the plugin.
 *
 * @link       https://makewebbetter.com
 * @since      1.0.0
 *
 * @package    Mwb_Cf7_Integration_With_Zoho
 * @subpackage Mwb_Cf7_Integration_With_Zoho/admin/partials/templates
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}
$response   = Mwb_Cf7_Integration_With_Zoho_Helper::get_logs();
$enable_log = Mwb_Cf7_Integration_With_Zoho_Helper::get_settings_details( 'logs' );

?>
<div class="mwb-zcf7__logs-wrap" id="mwb-zcf7-logs" ajax_url="<?php echo esc_attr( admin_url( 'admin-ajax.php' ) ); ?>">
	<div class="mwb-zcf7__logo-wrap">
		<div class="mwb-zcf7__logo-zoho">
			<img src="<?php echo esc_url( ZOHO_CF7_INTEGRATION_URL . 'admin/images/zoho-logo.png' ); ?>" alt="<?php esc_html_e( 'Zoho', 'mwb-cf7-integration-with-zoho' ); ?>">
		</div>
		<div class="mwb-zcf7__logo-contact">
			<img src="<?php echo esc_url( ZOHO_CF7_INTEGRATION_URL . 'admin/images/contact-form.svg' ); ?>" alt="<?php esc_html_e( 'Zoho', 'mwb-cf7-integration-with-zoho' ); ?>">
		</div>
		<?php if ( $enable_log ) : ?>
			<?php if ( $response ) : ?>
				<ul class="mwb-logs__settings-list">
					<li class="mwb-logs__settings-list-item">
						<a id="mwb-zcf7-clear-log" href="javascript:void(0)" class="mwb-logs__setting-link">
							<?php esc_html_e( 'Clear Log', 'mwb-cf7-integration-with-zoho' ); ?>	
						</a>
					</li>
					<li class="mwb-logs__settings-list-item">
						<a id="mwb-zcf7-download-log" href="javascript:void(0)"  class="mwb-logs__setting-link">
							<?php esc_html_e( 'Download', 'mwb-cf7-integration-with-zoho' ); ?>	
						</a>
					</li>
				</ul>
			<?php endif; ?>
		<?php endif; ?>
	</div>
	<div>
		<div>
			<?php if ( $enable_log ) : ?>
			<div class="mwb-zcf7__logs-table-wrap">
				<table id="mwb-zcf7-table" class="display mwb-zoho__logs-table dt-responsive nowrap" style="width: 100%;">
					<thead>
						<tr>
							<th><?php esc_html_e( 'Expand', 'mwb-cf7-integration-with-zoho' ); ?></th>
							<th><?php esc_html_e( 'Feed', 'mwb-cf7-integration-with-zoho' ); ?></th>
							<th><?php esc_html_e( 'Feed ID', 'mwb-cf7-integration-with-zoho' ); ?></th>
							<th><?php esc_html_e( 'Zoho Object', 'mwb-cf7-integration-with-zoho' ); ?></th>
							<th><?php esc_html_e( 'Zoho ID', 'mwb-cf7-integration-with-zoho' ); ?></th>
							<th><?php esc_html_e( 'Event', 'mwb-cf7-integration-with-zoho' ); ?></th>
							<th><?php esc_html_e( 'Timestamp', 'mwb-cf7-integration-with-zoho' ); ?></th>
							<th class=""><?php esc_html_e( 'Request', 'mwb-cf7-integration-with-zoho' ); ?></th>
							<th class=""><?php esc_html_e( 'Response', 'mwb-cf7-integration-with-zoho' ); ?></th>
						</tr>
					</thead>
				</table>
			</div>
			<?php else : ?>
				<div class="mwb-content-wrap">
					<?php esc_html_e( 'Please enable the logs from ', 'mwb-cf7-integration-with-zoho' ); ?><a href="<?php echo esc_url( 'admin.php?page=mwb_zoho_cf7&tab=settings' ); ?>" target="_blank"><?php esc_html_e( 'Settings tab', 'mwb-cf7-integration-with-zoho' ); ?></a>
				</div>
			<?php endif; ?>
		</div>
	</div>
</div>
