<?php
/**
 * Provide a admin area view for the plugin
 *
 * This file is used to markup the settings page.
 *
 * @link       https://makewebbetter.com
 * @since      1.0.0
 *
 * @package    Mwb_Cf7_Integration_With_Zoho
 * @subpackage Mwb_Cf7_Integration_With_Zoho/admin/partials/templates
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

if ( isset( $_POST['mwb_zcf7_submit_setting'] ) ) {

	/* Nonce verification */
	check_admin_referer( 'mwb_zoho_cf7_setting', 'zoho_cf7_setting_nonce' );

	$formdata = ! empty( $_POST['mwb_setting'] ) ? map_deep( wp_unslash( $_POST['mwb_setting'] ), 'sanitize_text_field' ) : '';
	$response = apply_filters( 'mwb_zcf7_save', $formdata, 'setting' );
}

$option = get_option( 'mwb_zcf7_setting', Mwb_Cf7_Integration_With_Zoho_Helper::mwb_zcf7_default_settings() );

?>

<div class="mwb_zcf7__account-wrap">

	<div class="mwb-zcf7__logo-wrap">
		<div class="mwb-zcf7__logo-zoho">
			<img src="<?php echo esc_url( ZOHO_CF7_INTEGRATION_URL . 'admin/images/zoho-logo.png' ); ?>" alt="<?php esc_html_e( 'Zoho', 'mwb-cf7-integration-with-zoho' ); ?>">
		</div>
		<div class="mwb-zcf7__logo-contact">
			<img src="<?php echo esc_url( ZOHO_CF7_INTEGRATION_URL . 'admin/images/contact-form.svg' ); ?>" alt="<?php esc_html_e( 'Zoho', 'mwb-cf7-integration-with-zoho' ); ?>">
		</div>
	</div>

	<?php
	if ( ! empty( $response ) && is_array( $response ) ) {

		if ( array_key_exists( 'email_error', $response ) ) {
			unset( $response['db_response'] );
			Mwb_Cf7_Integration_With_Zoho_Admin::mwb_zcf7_notices( $response['email_error']['class'], $response['email_error']['message'] );
		}

		if ( array_key_exists( 'db_response', $response ) ) {
			Mwb_Cf7_Integration_With_Zoho_Admin::mwb_zcf7_notices( $response['db_response']['class'], $response['db_response']['message'] );
		}

		if ( array_key_exists( 'error', $response ) ) {
			Mwb_Cf7_Integration_With_Zoho_Admin::mwb_zcf7_notices( $response['error']['class'], $response['error']['message'] );
		}
	}
	?>

	<form method="post" id="mwb_zcf7_settings_form">
		<?php wp_nonce_field( 'mwb_zoho_cf7_setting', 'zoho_cf7_setting_nonce' ); ?>
		<div class="mwb_zcf7_table_wrapper">
			<table class="mwb_zcf7_table">
				<tbody>

					<!-- Enable logs start -->
					<tr>
						<th>
							<label><?php esc_html_e( 'Enable logs', 'mwb-cf7-integration-with-zoho' ); ?></label>
						</th>

						<td>
							<?php
							$desc = esc_html__( 'Enable logging of all the form data to be sent over zoho', 'mwb-cf7-integration-with-zoho' );
							echo esc_html( Mwb_Cf7_Integration_With_Zoho_Admin::mwb_zcf7_tooltip( $desc ) );

							$enable_logs = ! empty( $option['enable_logs'] ) ? sanitize_text_field( wp_unslash( $option['enable_logs'] ) ) : '';
							?>
							<input type="checkbox" name="mwb_setting[enable_logs]" value="yes" <?php checked( 'yes', $enable_logs ); ?>>
						</td>
					</tr>
					<!-- Enable logs end-->

					<!-- Data delete start -->
					<tr>
						<th>
							<label><?php esc_html_e( 'Plugin Data', 'mwb-cf7-integration-with-zoho' ); ?></label>
						</th>

						<td>
							<?php
							$desc = esc_html__( 'Enable to delete the plugin data after uninstallation of plugin', 'mwb-cf7-integration-with-zoho' );
							echo esc_html( Mwb_Cf7_Integration_With_Zoho_Admin::mwb_zcf7_tooltip( $desc ) );

							$data_delete = ! empty( $option['data_delete'] ) ? sanitize_text_field( wp_unslash( $option['data_delete'] ) ) : '';
							?>
							<input type="checkbox" name="mwb_setting[data_delete]" value="yes"  <?php checked( 'yes', $data_delete ); ?>>
						</td>
					</tr>
					<!-- data delete end -->

					<!-- Enable email notif start -->
					<tr>
						<th>
							<label><?php esc_html_e( 'Email notification', 'mwb-cf7-integration-with-zoho' ); ?></label>
						</th>

						<td>
							<?php
								$desc = esc_html__( 'Enable email notification on errors', 'mwb-cf7-integration-with-zoho' );
								echo esc_html( Mwb_Cf7_Integration_With_Zoho_Admin::mwb_zcf7_tooltip( $desc ) );

								$enable_notif = ! empty( $option['enable_notif'] ) ? sanitize_text_field( wp_unslash( $option['enable_notif'] ) ) : '';
							?>
							<input type="checkbox" name="mwb_setting[enable_notif]" value="yes" <?php checked( 'yes', $enable_notif ); ?> >
						</td>
					</tr>
					<!-- Enable email notif end -->

					<!-- Email field start -->
					<tr >
						<th>
						</th>
						<td>
							<div id="mwb_zcf7_email_notif" class="<?php echo esc_attr( ( 'yes' != $enable_notif ) ? 'is_hidden' : '' ); // @codingStandardsIgnoreLine ?>">
								<?php
									$desc = esc_html__( 'Enter email address. An email will be sent if any sort of error occurs', 'mwb-cf7-integration-with-zoho' );
									echo esc_html( Mwb_Cf7_Integration_With_Zoho_Admin::mwb_zcf7_tooltip( $desc ) );

									$email_notif = ! empty( $option['email_notif'] ) ? sanitize_email( wp_unslash( $option['email_notif'] ) ) : '';
								?>
								<input type="email" name="mwb_setting[email_notif]" value="<?php echo esc_html( $email_notif ); ?>" >
							</div>
						</td>
					</tr>	
					<!--Email field end  -->

					<!-- Delete logs start -->
					<tr>
						<th>
							<label><?php esc_html_e( 'Delete logs after N days', 'mwb-cf7-integration-with-zoho' ); ?></label>
						</th>

						<td>
							<?php
							$desc = esc_html__( 'This will delete the logs data after N no. of days', 'mwb-cf7-integration-with-zoho' );
							echo esc_html( Mwb_Cf7_Integration_With_Zoho_Admin::mwb_zcf7_tooltip( $desc ) );

							$delete_logs = ! empty( $option['delete_logs'] ) ? sanitize_text_field( wp_unslash( $option['delete_logs'] ) ) : 30;
							?>
							<input type="number" name="mwb_setting[delete_logs]" min="0" maxlenght="4" step="1" pattern="[0-9]" value="<?php echo esc_html( $delete_logs ); ?>">
						</td>
					</tr>
					<!-- Delete logs end -->

					<?php do_action( 'mwb_zcf7_add_settings' ); ?>

					<!-- Save settings start -->
					<tr>
						<th>
						</th>
						<td>
							<input type="submit" name="mwb_zcf7_submit_setting" class="mwb_zcf7_submit_setting" value="<?php esc_html_e( 'Save', 'mwb-cf7-integration-with-zoho' ); ?>" >
						</td>
					</tr>
					<!-- Save settings end -->

				</tbody>
			</table>
		</div>
	</form>
</div>
